.. _source:


.. raw:: html

     <br><br>

.. title:: Source


.. raw:: html

    <center><b>SOURCE</b></center><br>


**OTPCR**

.. raw:: html

     <br>

.. autosummary::
    :toctree: 
    :template: base.rst


    otpcr.caching
    otpcr.clients
    otpcr.command
    otpcr.decoder
    otpcr.default
    otpcr.encoder
    otpcr.excepts
    otpcr.locater
    otpcr.lookups
    otpcr.objects
    otpcr.package
    otpcr.persist
    otpcr.reactor
    otpcr.threads
    otpcr.utility
    otpcr.workdir


.. raw:: html

     <br>


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    otpcr.modules.err
    otpcr.modules.fnd
    otpcr.modules.irc
    otpcr.modules.log
    otpcr.modules.mod
    otpcr.modules.req
    otpcr.modules.rss
    otpcr.modules.thr
    otpcr.modules.upt
